### ### ### ### ### ### ### ### ### ### ### ### 
### ### ### APPENDIX TABLE 14 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ### ### 

emp_summary<-emp_af[,list(
  
  #### 
  female_r,
  age_r,
  agediff,
  parents,
  father,
  married3,
  married6,
  married9,
  injob_e,
  injob_r,
  ann_income_log_r,
  privatecompany_pj,
  soe_pj,
  federalgov_pj,
  regionalgov_pj,
  localgov_pj)]

stargazer(emp_summary,covariate.labels=c(
  "Individual is Female",
  "Individual Age",
  "Individual Age Difference from Relative in Federal Office",
  "Relative in Federal Office is Father",
  "Relative in Federal Office is Son or Daughter",
  "Relative in Federal Office is Spouse (3 yr. diff)",
  "Relative in Federal Office is Spouse (6 yr. diff)",
  "Relative in Federal Office is Spouse (9 yr. diff)",
  "Relative in Federal Office",
  "Individual Employed",
  "Individual Salary (log)",
  "Individual Works in Private Firm",
  "Individual Works in SOE",
  "Individual Works for Federal Government",
  "Individual Works for Regional Government",
  "Individual Works for Local Government"),header=FALSE,digits=3)


### ### ### ### ### ### ### ### ### ### ### ### 
### ### ### APPENDIX TABLE 15 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ### ### 

load(file=paste(User,"emp_af.Rda",sep=""))

emp_e<-emp_af[,list(num_relatives=uniqueN(person_id_r),
                    num_kids=uniqueN(person_id_r[parents==1]),
                    num_spouses=uniqueN(person_id_r[married6==1]),
                    avg_salary_in_office=mean(ann_income_e[injob_e==1],na.rm=TRUE),
                    bank=max(bank,na.rm=TRUE),
                    
                    female_e=max(female_e,na.rm=TRUE)
),by=c("person_id_e")]

emp_e[emp_e=="-Inf"]<-0
emp_e$married<-ifelse(emp_e$num_spouses>0,1,0)

emp_bank<-emp_e[,list(numemployees=uniqueN(person_id_e),
                      avgsalary=mean(avg_salary_in_office,na.rm=TRUE),
                      avg_num_relatives=mean(num_relatives,na.rm=TRUE),
                      avg_num_kids=mean(num_kids,na.rm=TRUE),
                      percmarried=mean(married,na.rm=TRUE),
                      percfemale=mean(female_e,na.rm=TRUE)
),
by=c("bank")]
emp_bank$bank<-c("MDM Bank","Lafko Bank","Nikoil Bank","Trast Bank","Converse Bank","Absolut Bank","Bank of Moscow","Rosbank","Moscow Industrial Bank","Sobinbank", "Moscow Credit Bank","Sovinkom Commercial Bank","Tandem Bank","Alma Bank","Avangard Bank","Mosnar Bank","TransCredit Bank","MezhTrust Bank","MTS Bank","Dialog Optim Bank")
emp_bank<-emp_bank[order(-numemployees)]

emp_bank$numemployees<-prettyNum(emp_bank$numemployees,big.mark = ",")
emp_bank$avgsalary<-prettyNum(thous_dol(emp_bank$avgsalary),big.mark = ",",digits=3)
emp_bank$avg_num_relatives<-round(emp_bank$avg_num_relatives,2)
emp_bank$avg_num_kids<-round(emp_bank$avg_num_kids,2)
emp_bank$percmarried<-round(emp_bank$percmarried*100,2)
emp_bank$percfemale<-round(emp_bank$percfemale*100,2)

colnames(emp_bank) <- c("Bank","Employees","Mean Salary (ths. $)","Mean # of Relatives","Mean # of Kids","Married (%)","Female (%)")


### ### ### ### ### ### ### ### ### ### ### ### 
### ### ### APPENDIX TABLE 16 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ### ### 

### Panel A

est1 <- felm(injob_r ~  injob_e | factor(year) + factor(person_id_r) | 0 | person_id_r, data= emp_af, exactDOF=TRUE)

est2 <- felm(injob_r ~  injob_e + female_r + logage_r| factor(year) | 0 | person_id_r, data=emp_af, exactDOF=TRUE)

est3 <- felm(injob_r ~  injob_e | factor(year) + factor(person_id_r) + factor(age_r) | 0 | person_id_r, data= emp_af, exactDOF=TRUE)

est4 <- felm(injob_r ~  injob_e | factor(year) + factor(person_id_r) + factor(person_id_r):yr_order| 0 | person_id_r, data= emp_af, exactDOF=TRUE)

est5 <- felm(injob_r ~  injob_e | factor(year) + factor(person_id_r) + factor(new_family_id):yr_order| 0 | person_id_r, data= emp_af, exactDOF=TRUE)

### Control Group Means

mean(emp_af$injob_r[emp_af$injob_e==0])
mean(emp_af$injob_r[emp_af$injob_e==0])
mean(emp_af$injob_r[emp_af$injob_e==0])
mean(emp_af$injob_r[emp_af$injob_e==0])
mean(emp_af$injob_r[emp_af$injob_e==0])

#### Panel B

est1 <- felm(ann_income_log_r ~  injob_e | factor(year) + factor(person_id_r) | 0 | person_id_r, data= emp_af, exactDOF=TRUE)

est2 <- felm(ann_income_log_r ~  injob_e + female_r + logage_r| factor(year) | 0 | person_id_r, data=emp_af, exactDOF=TRUE)

est3 <- felm(ann_income_log_r ~  injob_e | factor(year) + factor(person_id_r)+factor(age_r) | 0 | person_id_r, data= emp_af, exactDOF=TRUE)

est4 <- felm(ann_income_log_r ~  injob_e | factor(year) + factor(person_id_r) + factor(person_id_r):yr_order| 0 | person_id_r, data= emp_af, exactDOF=TRUE)

est5 <- felm(ann_income_log_r ~  injob_e | factor(year) + factor(person_id_r) + factor(new_family_id):yr_order| 0 | person_id_r, data= emp_af, exactDOF=TRUE)

### Control Group Means

mean(emp_af$ann_income_r[emp_af$injob_e==0],na.rm=TRUE)/30000
mean(emp_af$ann_income_r[emp_af$injob_e==0],na.rm=TRUE)/30000
mean(emp_af$ann_income_r[emp_af$injob_e==0],na.rm=TRUE)/30000
mean(emp_af$ann_income_r[emp_af$injob_e==0],na.rm=TRUE)/30000
mean(emp_af$ann_income_r[emp_af$injob_e==0],na.rm=TRUE)/30000


### ### ### ### ### ### ### ### ### ### ### ### 
### ### ### APPENDIX TABLE 17 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ### ### 

emp_af10<-subset(emp_af, bank<=9)

### Panel A

est1 <- felm(injob_r ~  injob_e | factor(year) + factor(person_id_r) | 0 | person_id_r, data= emp_af10, exactDOF=TRUE)

est2 <- felm(injob_r ~  injob_e + female_r + logage_r| factor(year) | 0 | person_id_r, data=emp_af10, exactDOF=TRUE)

est3 <- felm(injob_r ~  injob_e | factor(year) + factor(person_id_r) + factor(age_r) | 0 | person_id_r, data= emp_af10, exactDOF=TRUE)

est4 <- felm(injob_r ~  injob_e | factor(year) + factor(person_id_r) + factor(person_id_r):yr_order| 0 | person_id_r, data= emp_af10, exactDOF=TRUE)

est5 <- felm(injob_r ~  injob_e | factor(year) + factor(person_id_r) + factor(new_family_id):yr_order| 0 | person_id_r, data= emp_af10, exactDOF=TRUE)

### Control Group Means

mean(emp_af10$injob_r[emp_af10$injob_e==0])
mean(emp_af10$injob_r[emp_af10$injob_e==0])
mean(emp_af10$injob_r[emp_af10$injob_e==0])
mean(emp_af10$injob_r[emp_af10$injob_e==0])
mean(emp_af10$injob_r[emp_af10$injob_e==0])


#### Panel B

est1 <- felm(ann_income_log_r ~  injob_e | factor(year) + factor(person_id_r) | 0 | person_id_r, data= emp_af10, exactDOF=TRUE)

est2 <- felm(ann_income_log_r ~  injob_e + female_r + logage_r| factor(year) | 0 | person_id_r, data=emp_af10, exactDOF=TRUE)

est3 <- felm(ann_income_log_r ~  injob_e | factor(year) + factor(person_id_r)+factor(age_r) | 0 | person_id_r, data= emp_af10, exactDOF=TRUE)

est4 <- felm(ann_income_log_r ~  injob_e | factor(year) + factor(person_id_r) + factor(person_id_r):yr_order| 0 | person_id_r, data= emp_af10, exactDOF=TRUE)

est5 <- felm(ann_income_log_r ~  injob_e | factor(year) + factor(person_id_r) + factor(new_family_id):yr_order| 0 | person_id_r, data= emp_af10, exactDOF=TRUE)

### Control Group Means

mean(emp_af10$ann_income_r[emp_af10$injob_e==0],na.rm=TRUE)/30000
mean(emp_af10$ann_income_r[emp_af10$injob_e==0],na.rm=TRUE)/30000
mean(emp_af10$ann_income_r[emp_af10$injob_e==0],na.rm=TRUE)/30000
mean(emp_af10$ann_income_r[emp_af10$injob_e==0],na.rm=TRUE)/30000
mean(emp_af10$ann_income_r[emp_af10$injob_e==0],na.rm=TRUE)/30000

