
### ### ### ### ### ### ### ### ###  ### ###
### ### ### APPENDIX TABLE 1 ### ### ### ###
### ### ### ### ### ### ### ### ### ### ###

load(file=paste(User,"pens_statistics_year.Rda",sep=""))



### ### ### ### ### ### ### ### ###  ### ###
### ### ### APPENDIX TABLE 2 ### ### ### ###
### ### ### ### ### ### ### ### ### ### ###

fed_emp$log_age<-log(fed_emp$age)
fed_emp$log_income<-log(fed_emp$income)
fed_emp<-subset(fed_emp, num_ministry==1)
est1<-felm(missing ~ log_age + log_income + female + numyears | 0 |0 | ministry, data=fed_emp)
est2<-felm(missing ~ log_age + log_income + female + numyears + factor(ministry) | 0 |0 | ministry, data=fed_emp)


### ### ### ### ### ### ### ### ###  ### ###
### ### ### APPENDIX TABLE 3 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ###

emp_e<-emp[,list(num_relatives=uniqueN(person_id_r),
                 num_kids=uniqueN(person_id_r[parents==1]),
                 num_spouses=uniqueN(person_id_r[married6==1]),
                 avg_salary_in_office=mean(ann_income_e[injob_e==1],na.rm=TRUE),
                 econdevelopment=max(econdevelopment,na.rm=TRUE),
                 education=max(education,na.rm=TRUE),
                 culture=max(culture,na.rm=TRUE),
                 labor=max(labor,na.rm=TRUE),
                 science=max(science,na.rm=TRUE),
                 transport=max(transport,na.rm=TRUE),
                 foreignaffairs=max(foreignaffairs,na.rm=TRUE),
                 emergency=max(emergency,na.rm=TRUE),
                 taxes=max(taxes,na.rm=TRUE),
                 energy=max(energy,na.rm=TRUE),
                 property=max(property,na.rm=TRUE),
                 naturalresources=max(naturalresources,na.rm=TRUE),
                 communications=max(communications,na.rm=TRUE),
                 finance=max(finance,na.rm=TRUE),
                 president=max(president,na.rm=TRUE),
                 female_e=max(female_e,na.rm=TRUE)
),by=c("person_id_e")]

emp_e[emp_e=="-Inf"]<-0
emp_e$married<-ifelse(emp_e$num_spouses>0,1,0)

emp_e$ministry[emp_e$econdevelopment>0]<-0
emp_e$ministry[emp_e$education>0]<-1
emp_e$ministry[emp_e$culture>0]<-2
emp_e$ministry[emp_e$labor>0]<-3
emp_e$ministry[emp_e$science>0]<-4
emp_e$ministry[emp_e$transport>0]<-5
emp_e$ministry[emp_e$foreignaffairs>0]<-6
emp_e$ministry[emp_e$emergency>0]<-7
emp_e$ministry[emp_e$taxes>0]<-8
emp_e$ministry[emp_e$property>0]<-9
emp_e$ministry[emp_e$energy>0]<-10
emp_e$ministry[emp_e$naturalresources>0]<-11
emp_e$ministry[emp_e$communications>0]<-12
emp_e$ministry[emp_e$finance>0]<-13
emp_e$ministry[emp_e$president>0]<-14

emp_ministry<-emp_e[,list(numemployees=uniqueN(person_id_e),
                          avgsalary=mean(avg_salary_in_office,na.rm=TRUE),
                          avg_num_relatives=mean(num_relatives,na.rm=TRUE),
                          avg_num_kids=mean(num_kids,na.rm=TRUE),
                          percmarried=mean(married,na.rm=TRUE),
                          percfemale=mean(female_e,na.rm=TRUE)
),
by=c("ministry")]
emp_ministry$numemployees<-prettyNum(emp_ministry$numemployees,big.mark = ",")
emp_ministry$avgsalary<-prettyNum(thous_dol(emp_ministry$avgsalary),big.mark = ",",digits=3)
emp_ministry$avg_num_relatives<-round(emp_ministry$avg_num_relatives,2)
emp_ministry$avg_num_kids<-round(emp_ministry$avg_num_kids,2)
emp_ministry$percmarried<-round(emp_ministry$percmarried*100,2)
emp_ministry$percfemale<-round(emp_ministry$percfemale*100,2)

setkey(emp_ministry,"ministry")
emp_ministry$ministry<-c('Economic Development','Education','Culture','Labor','Science and Technology','Transportation','Foreign Affairs','Emergency Situations','Taxes','Property Management','Energy','Natural Resources','Communications','Finance','Presidential Administration')

colnames(emp_ministry) <- c("Federal Institution","Employees","Mean Salary (ths. $)","Mean # of Relatives","Mean # of Kids","Married (%)","Female (%)")


### ### ### ### ### ### ### ### ###  ### ###
### ### ### APPENDIX TABLE 4 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ###


emp_summary<-emp[,list(
    female_r,
  age_r,
  agediff,
  parents,
  father,
  married3,
  married6,
  married9,
  injob_e,
  injob_r,
  ann_income_log_r,
  privatecompany_pj,
  soe_pj,
  federalgov_pj,
  regionalgov_pj,
  localgov_pj,
  infathersjob,
  salary_percentile_pj)]

stargazer(emp_summary,
          omit.summary.stat=c("p25","p75"),
          covariate.labels=c(
            "Individual is Female",
            "Individual Age",
            "Individual Age Difference from Relative in Federal Office",
            "Relative in Federal Office is Father",
            "Relative in Federal Office is Son or Daughter",
            "Relative in Federal Office is Spouse (3 yr. diff)",
            "Relative in Federal Office is Spouse (6 yr. diff)",
            "Relative in Federal Office is Spouse (9 yr. diff)",
            "Relative in Federal Office",
            "Individual Employed",
            "Individual Salary (log)",
            "Individual Works in Private Firm",
            "Individual Works in SOE",
            "Individual Works for Federal Government",
            "Individual Works for Regional Government",
            "Individual Works for Local Government",
            "Individual Works in Relative's Previous Job",
            "Individual Salary Rank"),header=FALSE,digits=3)




### ### ### ### ### ### ### ### ###  ### ###
### ### ### APPENDIX TABLE 5 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ###

load(file=paste(User,"tr_year.Rda",sep=""))

colnames(tr_year) <- c("Year","Volume (bil. rubles)","No. Transactions","No. Transactions w/ Description","(%)")


### ### ### ### ### ### ### ### ###  ### ###
### ### ### APPENDIX TABLE 6 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ###

firms$construction<-ifelse(firms$sector=="construction",1,0)
firms$manufacturing<-ifelse(firms$sector=="manufacturing",1,0)
firms$otherservices<-ifelse(firms$sector=="otherservices",1,0)
firms$trade<-ifelse(firms$sector=="trade",1,0)
firms$utilities<-ifelse(firms$sector=="utilities",1,0)
firms$mining<-ifelse(firms$sector=="mining",1,0)

firms_summary<-firms[,list(
  num_employees,
  relatives,
  fedgovreceipts_binary,
  thous_dol(fedgovreceipts),
  regionalgovreceipts_binary,
  thous_dol(regionalgovreceipts),
  localgovreceipts_binary,
  thous_dol(localgovreceipts),                       
  privatecompany,
  soe,
  age,
  construction,
  manufacturing,
  utilities,
  otherservices,
  trade,
  mining
)]

stargazer(firms_summary,
          omit.summary.stat=c("p25","p75"),
          
          covariate.labels=
            
            c("Number of Employees Per Year",
              "Number of Gov. Officials' Relatives",
              "Had Federal Government Contract",
              "Federal Government Contract (ths. \\$)",
              "Had Regional Government Contract",
              "Regional Government Contract (ths. \\$)",                                            "Had Local Government Contract",
              "Local Government Contract (ths. \\$)",      
              "Privately Owned",
              "State-Owned Enterprise",
              "Age (years)",
              "Construction",
              "Light Manufacturing",
              "Heavy Manufacturing",
              "Other Services",
              "Trade / Transportation",
              "Mining / Agriculture"
            ),header=FALSE,digits=2)



### ### ### ### ### ### ### ### ###  ### ###
### ### ### APPENDIX TABLE 7 ### ### ### ### 
### ### ### ### ### ### ### ### ### ### ###


firms_summary<-firms[firms$privatecompany==1][,list(
  num_employees,
  relatives,
  fedgovreceipts_binary,
  thous_dol(fedgovreceipts),
  regionalgovreceipts_binary,
  thous_dol(regionalgovreceipts),
  localgovreceipts_binary,
  thous_dol(localgovreceipts),                       
  age,
  construction,
  manufacturing,
  utilities,
  otherservices,
  trade,
  mining
)]

stargazer(firms_summary,
          omit.summary.stat=c("p25","p75"),
          covariate.labels=
            
            c("Number of Employees Per Year",
              "Number of Gov. Officials' Relatives",
              "Had Federal Government Contract",
              "Federal Government Contract (ths. \\$)",
              "Had Regional Government Contract",
              "Regional Government Contract (ths. \\$)",                                            "Had Local Government Contract",
              "Local Government Contract (ths. \\$)",      
              "Age (years)",
              "Construction",
              "Light Manufacturing",
              "Heavy Manufacturing",
              "Other Services",
              "Trade / Transportation",
              "Mining / Agriculture"
            ),header=FALSE,digits=2)
