### ### ### ### ### ### ### ### ### 
### ### ### FIGURE 3 ### ### ### ### 
### ### ### ### ### ### ### ### ###

est_minprivate <- felm(privatecompany_pj ~  injob_e+injob_e*education+injob_e*culture+ injob_e*econdevelopment+injob_e*labor+injob_e*transport+injob_e*foreignaffairs+injob_e*emergency+injob_e*taxes+injob_e*property+injob_e*energy+injob_e*naturalresources+injob_e*communications+injob_e*finance+injob_e*president | factor(year) + factor(person_id_r) | 0 | person_id_r, data= emp, exactDOF=TRUE)

coefs<-data.table(cbind(sector=row.names(est_minprivate$coefficients),coefs=as.numeric(as.vector(est_minprivate$coefficients)),se=as.numeric(est_minprivate$cse)))
coefs<-subset(coefs,sector!="injob_e" & se!=0)
coefs$se<-as.numeric(coefs$se)
coefs$coefs<-as.numeric(coefs$coefs)

interval <- -qnorm((1-0.95)/2)  # 95% multiplier
secbreaks = unique(as.character(coefs$sector))

coefs$sector <- factor(coefs$sector, levels = coefs$sector[order(coefs$coefs)])

zp1 <- ggplot(coefs) + geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) + geom_linerange(aes(x = sector, ymin = coefs - se*interval,ymax = coefs + se*interval), lwd = 1, position = position_dodge(width = 1/2)) + geom_pointrange(aes(x = sector, y = coefs, ymin = coefs - se*interval, ymax = coefs + se*interval),lwd = 1/2, position = position_dodge(width = 1/2),shape = 21, fill = "WHITE") + coord_flip() + theme_bw() + ggtitle(" ")+ scale_x_discrete(labels=rev(c(
  'Foreign Affairs',
  'Emergency Situations',
  'Energy',
  'Communications',
  'Finance',
  'Labor',
  'Tax Collection',
  'Natural Resources',
  'Transportation',
  'Presidential Administration',
  'Economic Development',
  'Education',
  'Culture',
  'Property Management')))+ ylab("\nPoint Estimate")+ xlab("Government Body")+ theme(axis.text=element_text(size=18),axis.title=element_text(size=18))
zp1



### ### ### ### ### ### ### ### ### 
### ### ### FIGURE 4 ### ### ### ### 
### ### ### ### ### ### ### ### ###


est_minprivate <- felm(privatecompany_pj ~  injob_e+injob_e*education+injob_e*culture+ injob_e*econdevelopment+injob_e*labor+injob_e*transport+injob_e*foreignaffairs+injob_e*emergency+injob_e*taxes+injob_e*property+injob_e*energy+injob_e*naturalresources+injob_e*communications+injob_e*finance+injob_e*president | factor(year) + factor(person_id_r) | 0 | person_id_r, data= emp, exactDOF=TRUE)

coefs<-data.table(cbind(sector=row.names(est_minprivate$coefficients),coefs=as.numeric(as.vector(est_minprivate$coefficients)),se=as.numeric(est_minprivate$cse)))
coefs<-subset(coefs,sector!="injob_e" & se!=0)
coefs$se<-as.numeric(coefs$se)
coefs$coefs<-as.numeric(coefs$coefs)

interval <- -qnorm((1-0.95)/2)  # 95% multiplier
secbreaks = unique(as.character(coefs$sector))

coefs$sector <- factor(coefs$sector, levels = coefs$sector[order(coefs$coefs)])

joinedcoefs<-merge(coefs,ministries_avg,by=c("sector"),all.x=TRUE,all.y=FALSE)
setkey(joinedcoefs,"sector")
joinedcoefs$label<-c('Communications','Culture','Economic Development','Education','Emergency Situations','Energy','Finance','Foreign Affairs','Labor','Natural Resources','Presidential Administration','Property Management','Taxes','Transportation')

joinedcoefs$numemployees_log<-log(joinedcoefs$numemployees)

ggplot(joinedcoefs, aes(totalpaynontax_log, coefs, label = label) ) +
  geom_point() + geom_smooth(method=lm)+xlab("Average Annual Federal Institution Payments (log)")+ylab("Fixed Effect Point Estimate")+ geom_text_repel(aes(label = label), 
                  box.padding = unit(0.45, "lines"))

ggplot(joinedcoefs, aes(numemployees_log, coefs, label = label) ) +
  geom_point() + geom_smooth(method=lm)+xlab("Average Annual Number of Employees (log)")+ylab("Fixed Effect Point Estimate")+ geom_text_repel(aes(label = label), 
                                                                                                                                                       box.padding = unit(0.45, "lines"))
